@@ -3,38 +3,27 @@
 package Pinto::DistributionSpec;
 
 use Moose;
-use MooseX::MarkAsMethods (autoclean => 1);
-use MooseX::Types::Moose qw(ArrayRef Str);
 
+use MooseX::Types::Moose qw(ArrayRef Str);
 use Pinto::Types qw(AuthorID);
-use Pinto::Util qw(throw);
 
 use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 #------------------------------------------------------------------------------
 
-
 has author => (
     is       => 'ro',
     isa      => AuthorID,
+    coerce   => 1,
     required => 1,
 );
 
 
-has author_canonical => (
-    is       => 'ro',
-    isa      => Str,
-    init_arg => undef,
-    default  => sub { uc $_[0]->author },
-    lazy     => 1,
-);
-
-
-has archive => (
+has basename => (
     is       => 'ro',
     isa      => Str,
     required => 1,
@@ -58,13 +47,13 @@ around BUILDARGS => sub {
         my @path_parts = split m{/+}x, $args[0];
 
         my $author   = shift @path_parts;  # First element
-        my $archive  = pop @path_parts;    # Last element
+        my $basename = pop @path_parts;    # Last element
         my $subdirs  = [ @path_parts ];    # Everything else
 
-        throw "Invalid distribution spec: $args[0]"
-            if not ($author and $archive);
+        confess "Invalid distribution spec: $args[0]"
+            if not ($author and $basename);
 
-        @args = (author => $author, subdirs => $subdirs, archive => $archive);
+        @args = (author => $author, subdirs => $subdirs, basename => $basename);
     }
 
     return $class->$orig(@args);
@@ -77,15 +66,15 @@ around BUILDARGS => sub {
 sub path {
     my ($self) = @_;
 
-    my $author   = $self->author_canonical;
+    my $author   = $self->author;
     my @subdirs  = @{ $self->subdirs };
-    my $archive  = $self->archive;
+    my $basename = $self->basename;
 
     return join '/', substr($author, 0, 1),
                      substr($author, 0, 2),
                      $author,
                      @subdirs,
-                     $archive;
+                     $basename;
 }
 
 #------------------------------------------------------------------------------
@@ -96,11 +85,11 @@ sub to_string {
 
     my $author   = $self->author;
     my @subdirs  = @{ $self->subdirs };
-    my $archive  = $self->archive;
+    my $basename = $self->basename;
 
     return join '/', $author,
                      @subdirs,
-                     $archive;
+                     $basename;
 }
 
 #------------------------------------------------------------------------------
@@ -110,7 +99,7 @@ __PACKAGE__->meta->make_immutable;
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
@@ -122,7 +111,7 @@ Pinto::DistributionSpec - Specifies a distribution by author and path fragments
 
 =head1 VERSION
 
-version 0.065_04
+version 0.037
 
 =head1 METHODS
 
@@ -138,7 +127,7 @@ context.  Returns the same result as the C<path> method.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -148,3 +137,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
