@@ -3,21 +3,15 @@
 package Pinto::PackageSpec;
 
 use Moose;
-use MooseX::MarkAsMethods (autoclean => 1);
+
 use MooseX::Types::Moose qw(Str);
+use Pinto::Types qw(Vers);
 
-use Module::CoreList;
-use English qw(-no_match_vars);
-
-use Pinto::Types qw(Version);
-use Pinto::Util qw(throw);
-
-use version;
 use overload ('""' => 'to_string');
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.037'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -30,7 +24,7 @@ has name => (
 
 has version => (
     is      => 'ro',
-    isa     => Version,
+    isa     => Vers,
     coerce  => 1,
     default => sub { version->parse(0) }
 );
@@ -43,7 +37,7 @@ around BUILDARGS => sub {
 
     my @args = @_;
     if (@args == 1 and not ref $args[0]) {
-        my ($name, $version) = split m{~}x, $_[0], 2;
+        my ($name, $version) = split m{-}x, $_[0], 2;
         @args = (name => $name, version => $version || 0);
     }
 
@@ -53,36 +47,9 @@ around BUILDARGS => sub {
 #------------------------------------------------------------------------------
 
 
-sub is_core {
-    my ($self, %args) = @_;
-
-    ## no critic qw(PackageVar);
-
-    my $pv = version->parse($args{in}) || $PERL_VERSION;
-    my $core_modules = $Module::CoreList::version{ $pv->numify + 0 };
-
-    throw "Invalid perl version $pv" if not $core_modules;
-
-    return 0 if not exists $core_modules->{$self->name};
-    return 0 if $self->version > $core_modules->{$self->name};
-    return 1;
-}
-
-#-------------------------------------------------------------------------------
-
-
-sub is_perl {
-    my ($self) = @_;
-
-    return $self->name eq 'perl' ? 1 : 0;
-}
-
-#-------------------------------------------------------------------------------
-
-
 sub to_string {
     my ($self) = @_;
-    return sprintf '%s~%s', $self->name, $self->version->stringify;
+    return sprintf '%s-%s', $self->name, $self->version->stringify;
 }
 
 #------------------------------------------------------------------------------
@@ -92,7 +59,7 @@ __PACKAGE__->meta->make_immutable;
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
@@ -104,22 +71,10 @@ Pinto::PackageSpec - Specifies a package by name and version
 
 =head1 VERSION
 
-version 0.065_04
+version 0.037
 
 =head1 METHODS
 
-=head2 is_core
-
-=head2 is_core(in => $version)
-
-Returns true if this package is satisfied by the perl core as-of a particular
-version.  If the version is not specified, it defaults to whatever version
-you are using now.
-
-=head2 is_perl()
-
-Returns true if this package is perl itself.
-
 =head2 to_string()
 
 Serializes this PackageSpec to its string form.  This method is called
@@ -127,7 +82,7 @@ whenever the PackageSpec is evaluated in string context.
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -137,3 +92,7 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
